@@ -88,10 +88,14 @@ void Xbmc::init()
 
 bool Xbmc::connected()
 {
-    qDebug() << "****" << XbmcConnection::connected();
     return XbmcConnection::connected();
 }
 
+QString Xbmc::connectionError()
+{
+    return XbmcConnection::connectionError();
+}
+
 AudioLibrary *Xbmc::audioLibrary()
 {
     return new AudioLibrary();
@@ -145,7 +149,6 @@ void Xbmc::setPort(int port)
 
 void Xbmc::connectToHost()
 {
-    qDebug() << "fdfdsfsdafas";
     XbmcConnection::connect(m_hostname, m_port);
 }
 
@@ -230,7 +233,8 @@ void Xbmc::connectionChanged()
     if(connected()) {
         init();
     }
-    emit connectedChanged();
+    qDebug() << "Connection changed to " << connected();
+    emit connectedChanged(connected());
 }
 
 void Xbmc::setVolume(int volume)
@@ -254,3 +258,8 @@ int Xbmc::volume()
 {
     return m_volume;
 }
+
+void Xbmc::quit()
+{
+    XbmcConnection::sendCommand("XBMC.Quit");
+}
